@@ -41,9 +41,10 @@ class StaleResult:
 
 
 class FindStaleProcessor:
-    def __init__(self):
+    def __init__(self, onchange=None):
         self.now = utcnow()
         self.results = defaultdict(dict)    # {what: {container: (cfg, [stale])}}
+        self.onchange = onchange
 
     def find(self, container, scope, getobj_meth, dt):
         # Identify the point in the past, before which the user must have logged on
@@ -81,10 +82,16 @@ class FindStaleProcessor:
                         sr.user.commit()
                     # TODO: Tighten this up to include ldap.error and anything from .ldapobj
                     except Exception as e:
+                        logger.exception(e)
                         sr.disabled_status = e
                     else:
                         sr.disabled_status = True
 
+                        message = "Disabled stale account {}".format(sr.user.dn)
+                        logger.info(message)
+                        if self.onchange:
+                            self.onchange(message=message)
+
         return total
 
     @property
@@ -287,11 +294,11 @@ def _build_plaintext_report(fs):
     return buf.getvalue()
 
 
-def find_and_process_stale_accounts(ad, config):
+def find_and_process_stale_accounts(ad, config, onchange=None):
     sacfg = config.stale_accounts
 
     # Find and disable (if configured)
-    fs = FindStaleProcessor()
+    fs = FindStaleProcessor(onchange=onchange)
 
     fs.process('user', sacfg.users, ad.get_users)
     fs.process('computer', sacfg.computers, ad.get_computers)
